nbxmpp.idlequeue.IdleCommand

Package nbxmpp :: Module idlequeue :: Class IdleCommand |
[hide private]
[frames] | no frames]

# Class IdleCommand

source code

Can be subclassed to execute commands asynchronously by the idlequeue. Result will be optained via file descriptor of created pipe

Instance Methods | [hide private]
__init__(self, on_result) | source code
set_idlequeue(self, idlequeue) | source code
_return_result(self) | source code
_compose_command_args(self) | source code
_compose_command_line(self) Return one line representation of command and its arguments | source code
wait_child(self) | source code
start(self) | source code
_start_nt(self) | source code
_start_posix(self) | source code
end(self) | source code
pollend(self) Called on stream failure | source code
pollin(self) Called on new read event | source code
read_timeout(self) Called when timeout happened | source code
Inherited from `IdleObject`: `pollout`

Instance Variables | [hide private]
Inherited from `IdleObject`: `fd`

Method Details | [hide private]

### __init__(self, on_result) (Constructor) | source code
Overrides: IdleObject.__init__

### set_idlequeue(self, idlequeue) | source code

### _return_result(self) | source code

### _compose_command_args(self) | source code

### _compose_command_line(self) | source code
Return one line representation of command and its arguments

### wait_child(self) | source code

### start(self) | source code

### _start_nt(self) | source code

### _start_posix(self) | source code

### end(self) | source code

### pollend(self) | source code
Called on stream failure Overrides: IdleObject.pollend (inherited documentation)

### pollin(self) | source code
Called on new read event Overrides: IdleObject.pollin (inherited documentation)

### read_timeout(self) | source code
Called when timeout happened Overrides: IdleObject.read_timeout (inherited documentation)